/***************************************************************************
 *   Copyright (C) 2008-2010 by Marcel Hasler                              *
 *   mahasler@gmail.com                                                    *
 *                                                                         *
 *   This file is part of KOSD.                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation, either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the          *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program. If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/

#include "compactosd.h"
#include "configuration.h"
#include "kosdd.h"
#include "standardosd.h"

#include "kosd/kosd.h"

#include <KPluginFactory>
#include <Plasma/Theme>

#include <QMessageBox>

K_PLUGIN_FACTORY(KOsdDFactory, registerPlugin<KOsdD>();)
K_EXPORT_PLUGIN(KOsdDFactory("kosd"))

static int clamp(int value, int low, int high)
{
    if (value < low)
        return low;
    else if (value > high)
        return high;
    return value;
}


KOsdD::KOsdD(QObject* parent, const QList<QVariant>&)
    : KDEDModule(parent),
      m_osd(0)
{
    connect(Plasma::Theme::defaultTheme(), SIGNAL(themeChanged()), this, SLOT(parseConfiguration()));
    parseConfiguration();
}


KOsdD::~KOsdD()
{
    delete m_osd;
}


void KOsdD::showSvgOsd(const QString &svg, const QStringList &elements, const QString &text, int percent)
{
    m_osd->show(svg, elements, text, clamp(percent, 0, 100));
}


void KOsdD::showPixmapOsd(const QString &pixmap, const QString &text, int percent)
{
    m_osd->show(pixmap, text, clamp(percent, 0, 100));
}


void KOsdD::parseConfiguration()
{
    if (m_osd)
        delete m_osd;

    Configuration::self()->readConfig();
    if (Configuration::self()->type() == 0)
        m_osd = new StandardOsd();
    else
        m_osd = new CompactOsd();

    m_osd->setOpacity(Configuration::self()->opacity());
    m_osd->setPosition(Configuration::self()->hPos(), Configuration::self()->vPos());
    m_osd->setPrimaryScreenLock(Configuration::self()->primaryScreen());
    m_osd->setTimeout(1000*Configuration::self()->timeout());
}

#include "kosdd.moc"
