/***************************************************************************
 *   Copyright (C) 2008-2010 by Marcel Hasler                              *
 *   mahasler@gmail.com                                                    *
 *                                                                         *
 *   This file is part of KOSD.                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation, either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the          *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program. If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/

#include "mixer.h"

#include <QtDBus>

class MixerPrivate
{
public:
    static QString masterDeviceIndex();    
};


QString MixerPrivate::masterDeviceIndex()
{
    QDBusMessage m = QDBusMessage::createMethodCall("org.kde.kmix", "/Mixer0", "", "masterDeviceIndex");
    QDBusReply<QString> reply = QDBusConnection::sessionBus().call(m);

    QString index = "Master:0";
    if (reply.isValid())
        index = reply.value();
    return index;
}


void Mixer::increaseVolume()
{
    qlonglong volume = absoluteVolume();

    QDBusMessage m = QDBusMessage::createMethodCall("org.kde.kmix", "/Mixer0", "", "setAbsoluteVolume");
    m << MixerPrivate::masterDeviceIndex();
    m << volume + 1;
    QDBusConnection::sessionBus().call(m);
}


void Mixer::decreaseVolume()
{
    qlonglong volume = absoluteVolume();

    QDBusMessage m = QDBusMessage::createMethodCall("org.kde.kmix", "/Mixer0", "", "setAbsoluteVolume");
    m << MixerPrivate::masterDeviceIndex();
    m << volume - 1;
    QDBusConnection::sessionBus().call(m);
}


int Mixer::absoluteVolume()
{
    QDBusMessage m = QDBusMessage::createMethodCall("org.kde.kmix", "/Mixer0", "", "absoluteVolume");
    m << MixerPrivate::masterDeviceIndex();
    QDBusReply<qlonglong> reply = QDBusConnection::sessionBus().call(m);

    qlonglong volume = 0;
    if (reply.isValid())
        volume = reply.value();

    return static_cast<int>(volume);
}


int Mixer::volume()
{
    QDBusMessage m = QDBusMessage::createMethodCall("org.kde.kmix", "/Mixer0", "", "masterVolume");
    QDBusReply<int> reply = QDBusConnection::sessionBus().call(m);

    int volume = 0;
    if (reply.isValid())
        volume = reply.value();

    return volume;
}


void Mixer::setMuted(bool mute)
{
    QDBusMessage m = QDBusMessage::createMethodCall("org.kde.kmix", "/Mixer0", "", "setMute");
    m << MixerPrivate::masterDeviceIndex();
    m << mute;
    QDBusConnection::sessionBus().call(m);
}


bool Mixer::isMuted()
{
    QDBusMessage m = QDBusMessage::createMethodCall("org.kde.kmix", "/Mixer0", "", "mute");
    m << MixerPrivate::masterDeviceIndex();
    QDBusReply<bool> reply = QDBusConnection::sessionBus().call(m);

    bool mute = true;
    if (reply.isValid())
        mute = reply.value();

    return mute;
}
