/***************************************************************************
 *   Copyright (C) 2008-2011 by Marcel Hasler                              *
 *   mahasler@gmail.com                                                    *
 *                                                                         *
 *   This file is part of KOSD.                                            *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation, either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the          *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program. If not, see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/

#include "powermanager.h"

#include <KAuth/Action>

#include <Solid/AcAdapter>
#include <Solid/Battery>
#include <Solid/Device>

void PowerManager::increaseBrightness()
{
    int current = brightness();
    if (current < 100)
    {
        KAuth::Action action("org.kde.powerdevil.backlighthelper.setbrightness");
        action.setHelperID("org.kde.powerdevil.backlighthelper");
        action.addArgument("brightness", (current >= 90) ? 100 : (current + 10));
        action.execute();
    }
}


void PowerManager::decreaseBrightness()
{
    int current = brightness();
    if (current > 0)
    {
        KAuth::Action action("org.kde.powerdevil.backlighthelper.setbrightness");
        action.setHelperID("org.kde.powerdevil.backlighthelper");
        action.addArgument("brightness", (current <= 10) ? 0 : (current - 10));
        action.execute();
    }
}


int PowerManager::brightness()
{
    int result = 0;

    KAuth::Action action("org.kde.powerdevil.backlighthelper.brightness");
    action.setHelperID("org.kde.powerdevil.backlighthelper");
    KAuth::ActionReply reply = action.execute();
    if (reply.succeeded())
        result = reply.data()["brightness"].toInt();

    return result;
}


int PowerManager::batteryCharge()
{
    QList<Solid::Device> batteries = Solid::Device::listFromType(Solid::DeviceInterface::Battery);
    if (batteries.size() == 0)
        return 0;

    int charge = 0;

    Solid::Device device;
    foreach (device, batteries)
    {
        Solid::Battery *battery = device.as<Solid::Battery>();
        charge += battery->chargePercent();
    }

    charge /= batteries.size();
    return charge;
}


bool PowerManager::acAdapterPlugged()
{
    QList<Solid::Device> adapters = Solid::Device::listFromType(Solid::DeviceInterface::AcAdapter);
    if (adapters.size() == 0)
        return false;

    const Solid::AcAdapter *adapter = adapters.at(0).as<Solid::AcAdapter>();
    return adapter->isPlugged();
}
